@@ -4,4 +4,4 @@ def do_stuff(*args)
   :stuff
 end
 
-Concurrent.use_simple_logger Logger::DEBUG
+Concurrent.use_simple_logger :DEBUG
