@@ -2,14 +2,13 @@
 
 #include "atomic_boolean.h"
 #include "atomic_reference.h"
-#include "ruby_193_compatible.h"
 
 void atomic_boolean_mark(void *value) {
   rb_gc_mark_maybe((VALUE) value);
 }
 
 VALUE atomic_boolean_allocate(VALUE klass) {
-  return rb_data_object_alloc(klass, (void *) Qfalse, atomic_boolean_mark, NULL);
+  return rb_data_object_wrap(klass, (void *) Qfalse, atomic_boolean_mark, NULL);
 }
 
 VALUE method_atomic_boolean_initialize(int argc, VALUE* argv, VALUE self) {
