@@ -1,8 +1,9 @@
 require_relative 'buffered_shared'
+require 'concurrent/channel/buffer/base'
 
 module Concurrent::Channel::Buffer
 
-  RSpec.describe Base, edge: true, notravis: true do
+  RSpec.describe Base, edge: true do
 
     subject { described_class.new }
 
