@@ -1,8 +1,9 @@
 require_relative 'buffered_shared'
+require 'concurrent/channel/buffer/dropping'
 
 module Concurrent::Channel::Buffer
 
-  RSpec.describe Dropping, edge: true, notravis: true do
+  RSpec.describe Dropping, edge: true do
 
     subject { described_class.new(10) }
 
