@@ -1,8 +1,9 @@
 require_relative 'timing_buffer_shared'
+require 'concurrent/channel/buffer/ticker'
 
 module Concurrent::Channel::Buffer
 
-  RSpec.describe Ticker, edge: true, notravis: true do
+  RSpec.describe Ticker, edge: true do
 
     let(:delay) { 0.1 }
     subject { described_class.new(delay) }
