@@ -1,6 +1,8 @@
+require 'concurrent/configuration'
+
 module Concurrent
 
-   RSpec.describe 'configuration', notravis: true do
+   RSpec.describe 'configuration' do
 
     context 'global executors' do
 
