@@ -1,4 +1,7 @@
 require_relative 'collection_each_shared'
+require 'concurrent/map'
+require 'concurrent/atomic/count_down_latch'
+
 Thread.abort_on_exception = true
 
 module Concurrent
@@ -7,6 +10,23 @@ module Concurrent
       @cache = described_class.new
     end
 
+    it 'default_proc is called with the Concurrent::Map and the key' do
+      map = Concurrent::Map.new do |h, k|
+        [h, k]
+      end
+      expect(map[:foo][0]).to be(map)
+      expect(map[:foo][1]).to eq(:foo)
+    end
+
+    it 'default_proc is called with the Concurrent::Map and the key after #dup' do
+      map = Concurrent::Map.new do |h, k|
+        [h, k]
+      end
+      copy = map.dup
+      expect(copy[:foo][0]).to be(copy)
+      expect(copy[:foo][1]).to eq(:foo)
+    end
+
     it 'concurrency' do
       (1..Concurrent::ThreadSafe::Test::THREADS).map do |i|
         in_thread do
@@ -42,6 +62,14 @@ module Concurrent
     end
 
     describe '#compute_if_absent' do
+      it 'works in default_proc' do
+        map = Concurrent::Map.new do |map, key|
+          map.compute_if_absent(key) { key * 2 }
+        end
+        expect(map[3]).to eq 6
+        expect(map.keys).to eq [3]
+      end
+
       it 'common' do
         with_or_without_default_proc do
           expect_size_change(3) do
@@ -527,10 +555,9 @@ module Concurrent
 
       it 'with return' do
         with_or_without_default_proc do
-          r = fetch_with_return
-          # r = lambda do
-          #   @cache.fetch(:a) { return 10 }
-          # end.call
+          r = -> do
+            @cache.fetch(:a) { return 10 }
+          end.call
 
           expect_no_size_change do
             expect(10).to    eq r
@@ -609,7 +636,9 @@ module Concurrent
 
       it 'with return' do
         with_or_without_default_proc do
-          r = fetch_or_store_with_return
+          r = -> do
+            @cache.fetch_or_store(:a) { return 10 }
+          end.call
 
           expect_no_size_change do
             expect(10).to    eq r
@@ -773,8 +802,8 @@ module Concurrent
         end
         expect_no_size_change cache do
           expect_size_change 1, dupped do
-            expect(:default_value).to eq dupped[:d]
-            expect(false).to          eq cache.key?(:d)
+            expect(dupped[:d]).to eq :default_value
+            expect(cache.key?(:d)).to eq false
           end
         end
       end
@@ -811,12 +840,18 @@ module Concurrent
 
     def with_or_without_default_proc(&block)
       block.call(false)
-      @cache = Concurrent::Map.new { |h, k| h[k] = :default_value }
+      @cache = Concurrent::Map.new { |h, k|
+        expect(h).to be_kind_of(Concurrent::Map)
+        h[k] = :default_value
+      }
       block.call(true)
     end
 
     def cache_with_default_proc(default_value = 1)
-      Concurrent::Map.new { |cache, k| cache[k] = default_value }
+      Concurrent::Map.new do |map, k|
+        expect(map).to be_kind_of(Concurrent::Map)
+        map[k] = default_value
+      end
     end
 
     def expect_size_change(change, cache = @cache, &block)
@@ -905,20 +940,5 @@ module Concurrent
       end
       expect(keys.all? { |k| @cache[k] == k.key }).to be_truthy
     end
-
-    # Took out for compatibility with Rubinius, see https://github.com/rubinius/rubinius/issues/1312
-    def fetch_with_return
-      lambda do
-        @cache.fetch(:a) { return 10 }
-      end.call
-    end
-
-    # Took out for compatibility with Rubinius, see https://github.com/rubinius/rubinius/issues/1312
-    def fetch_or_store_with_return
-      lambda do
-        @cache.fetch_or_store(:a) { return 10 }
-      end.call
-    end
-
   end
 end
