@@ -1,3 +1,8 @@
+require 'concurrent/promise'
+require 'concurrent/executor/simple_executor_service'
+require 'concurrent/executor/single_thread_executor'
+require 'concurrent/atomic/count_down_latch'
+
 require_relative 'ivar_shared'
 require_relative 'thread_arguments_shared'
 
@@ -195,6 +200,16 @@ module Concurrent
             end_latch.count_down
           end
         end
+
+        context "when called on child after parent completes" do
+          let(:parent_promise) { Concurrent::Promise.execute { 1 + 1 }.tap { |p| p.wait } }
+          it 'sets state to :pending immediately' do
+            latch = CountDownLatch.new
+            child_promise = parent_promise.then { |_| latch.wait }.execute
+            expect(child_promise.state).to eq(:pending)
+            latch.count_down
+          end
+        end
       end
     end
 
